OC.L10N.register(
    "core",
    {
    "Please select a file." : "გთხოვთ, აირჩიოთ ფაილი.",
    "File is too big" : "ფაილი ზედმეტად დიდია",
    "The selected file is not an image." : "არჩეული ფაილი არ არის სურათი.",
    "The selected file cannot be read." : "არჩეული ფაილი ვერ იკითხება.",
    "The file was uploaded" : "ფაილი ატვირთულ იქნა",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს MAX_FILE_SIZE დირექტივას, რომელიც მითითებული იყო HTML ფორმაში",
    "The file was only partially uploaded" : "ფაილი მხოლოდ ნაწილობრივ აიტვირთა",
    "No file was uploaded" : "არცერთი ფაილი არ აიტვირთა",
    "Missing a temporary folder" : "დროებითი საქაღალდე ვერ იძებნება",
    "Could not write file to disk" : "დისკზე ჩაწერა ვერ მოხერხდა",
    "A PHP extension stopped the file upload" : "PHP გაფართოებამ შეწყვიტა ფაილის ატვირთვა",
    "Invalid file provided" : "მითითებულია არასწორი ფაილი",
    "No image or file provided" : "სურათი ან ფაილი არ არის მითითებული",
    "Unknown filetype" : "უცნობი ფაილის ტიპი",
    "An error occurred. Please contact your admin." : "მოხდა შეცდომა. გთხოვთ, დაუკავშირდეთ თქვენს ადმინისტრატორს.",
    "Invalid image" : "არასწორი სურათი",
    "No temporary profile picture available, try again" : "No temporary profile picture available, try again",
    "No crop data provided" : "No crop data provided",
    "No valid crop data provided" : "No valid crop data provided",
    "Crop is not square" : "Crop is not square",
    "State token does not match" : "State token does not match",
    "Invalid app password" : "Invalid app password",
    "Could not complete login" : "Could not complete login",
    "State token missing" : "State token missing",
    "Your login token is invalid or has expired" : "Your login token is invalid or has expired",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "This community release of Nextcloud is unsupported and push notifications are limited.",
    "Login" : "Login",
    "Password reset is disabled" : "Password reset is disabled",
    "Could not reset password because the token is expired" : "Could not reset password because the token is expired",
    "Could not reset password because the token is invalid" : "Could not reset password because the token is invalid",
    "Password is too long. Maximum allowed length is 469 characters." : "Password is too long. Maximum allowed length is 469 characters.",
    "%s password reset" : "%s password reset",
    "Password reset" : "Password reset",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Click the following button to reset your password. If you have not requested the password reset, then ignore this email.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Click the following link to reset your password. If you have not requested the password reset, then ignore this email.",
    "Reset your password" : "Reset your password",
    "Task not found" : "Task not found",
    "Internal error" : "Internal error",
    "Not found" : "Not found",
    "Requested task type does not exist" : "Requested task type does not exist",
    "Necessary language model provider is not available" : "Necessary language model provider is not available",
    "No text to image provider is available" : "No text to image provider is available",
    "Image not found" : "Image not found",
    "No translation provider available" : "No translation provider available",
    "Could not detect language" : "Could not detect language",
    "Unable to translate" : "Unable to translate",
    "Nextcloud Server" : "Nextcloud Server",
    "Some of your link shares have been removed" : "Some of your link shares have been removed",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Due to a security bug we had to remove some of your link shares. Please see the link for more information.",
    "Learn more ↗" : "Learn more ↗",
    "Preparing update" : "Preparing update",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Repair step:",
    "Repair info:" : "Repair info:",
    "Repair warning:" : "Repair warning:",
    "Repair error:" : "Repair error:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Please use the command line updater because updating via browser is disabled in your config.php.",
    "Turned on maintenance mode" : "Turned on maintenance mode",
    "Turned off maintenance mode" : "Turned off maintenance mode",
    "Maintenance mode is kept active" : "Maintenance mode is kept active",
    "Updating database schema" : "Updating database schema",
    "Updated database" : "Updated database",
    "Update app \"%s\" from App Store" : "Update app \"%s\" from App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)",
    "Updated \"%1$s\" to %2$s" : "Updated \"%1$s\" to %2$s",
    "Set log level to debug" : "Set log level to debug",
    "Reset log level" : "Reset log level",
    "Starting code integrity check" : "Starting code integrity check",
    "Finished code integrity check" : "Finished code integrity check",
    "%s (incompatible)" : "%s (incompatible)",
    "The following apps have been disabled: %s" : "The following apps have been disabled: %s",
    "Already up to date" : "Already up to date",
    "Error occurred while checking server setup" : "Error occurred while checking server setup",
    "For more details see the {linkstart}documentation ↗{linkend}." : "For more details see the {linkstart}documentation ↗{linkend}.",
    "unknown text" : "unknown text",
    "Hello world!" : "Hello world!",
    "sunny" : "sunny",
    "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
    "Hello {name}" : "Hello {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>These are your search results<script>alert(1)</script></strong>",
    "new" : "new",
    "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "The update is in progress, leaving this page might interrupt the process in some environments.",
    "Update to {version}" : "Update to {version}",
    "An error occurred." : "An error occurred.",
    "Please reload the page." : "Please reload the page.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>.",
    "Continue to {productName}" : "Continue to {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["The update was successful. Redirecting you to {productName} in %n second.","The update was successful. Redirecting you to {productName} in %n seconds."],
    "Applications menu" : "Applications menu",
    "Apps" : "Apps",
    "More apps" : "More apps",
    "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} notifications"],
    "No" : "No",
    "Yes" : "Yes",
    "Create share" : "Create share",
    "Failed to add the public link to your Nextcloud" : "Failed to add the public link to your Nextcloud",
    "Custom date range" : "Custom date range",
    "Pick start date" : "Pick start date",
    "Pick end date" : "Pick end date",
    "Search in date range" : "Search in date range",
    "Unified search" : "Unified search",
    "Search apps, files, tags, messages" : "Search apps, files, tags, messages",
    "Date" : "Date",
    "Today" : "Today",
    "Last 7 days" : "Last 7 days",
    "Last 30 days" : "Last 30 days",
    "This year" : "This year",
    "Last year" : "Last year",
    "Search people" : "Search people",
    "People" : "People",
    "Filter in current view" : "Filter in current view",
    "Load more results" : "Load more results",
    "Search in" : "Search in",
    "Searching …" : "Searching …",
    "Start typing to search" : "Start typing to search",
    "No matching results" : "No matching results",
    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}",
    "Log in" : "Log in",
    "Logging in …" : "Logging in …",
    "Server side authentication failed!" : "Server side authentication failed!",
    "Please contact your administrator." : "Please contact your administrator.",
    "Temporary error" : "Temporary error",
    "Please try again." : "Please try again.",
    "An internal error occurred." : "An internal error occurred.",
    "Please try again or contact your administrator." : "Please try again or contact your administrator.",
    "Password" : "პაროლი",
    "Log in to {productName}" : "Log in to {productName}",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds.",
    "Account name or email" : "Account name or email",
    "Log in with a device" : "Log in with a device",
    "Your account is not setup for passwordless login." : "Your account is not setup for passwordless login.",
    "Browser not supported" : "Browser not supported",
    "Passwordless authentication is not supported in your browser." : "Passwordless authentication is not supported in your browser.",
    "Your connection is not secure" : "Your connection is not secure",
    "Passwordless authentication is only available over a secure connection." : "Passwordless authentication is only available over a secure connection.",
    "Reset password" : "Reset password",
    "Couldn't send reset email. Please contact your administrator." : "Couldn't send reset email. Please contact your administrator.",
    "Password cannot be changed. Please contact your administrator." : "Password cannot be changed. Please contact your administrator.",
    "Back to login" : "Back to login",
    "New password" : "New password",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?",
    "I know what I'm doing" : "I know what I'm doing",
    "Resetting password" : "Resetting password",
    "Recommended apps" : "Recommended apps",
    "Loading apps …" : "Loading apps …",
    "Could not fetch list of apps from the App Store." : "Could not fetch list of apps from the App Store.",
    "App download or installation failed" : "App download or installation failed",
    "Cannot install this app because it is not compatible" : "Cannot install this app because it is not compatible",
    "Cannot install this app" : "Cannot install this app",
    "Skip" : "Skip",
    "Installing apps …" : "Installing apps …",
    "Install recommended apps" : "Install recommended apps",
    "Schedule work & meetings, synced with all your devices." : "Schedule work & meetings, synced with all your devices.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Keep your colleagues and friends in one place without leaking their private info.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simple email app nicely integrated with Files, Contacts and Calendar.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
    "Distraction free note taking app." : "Distraction free note taking app.",
    "Settings menu" : "Settings menu",
    "Avatar of {displayName}" : "Avatar of {displayName}",
    "Search contacts" : "Search contacts",
    "Reset search" : "Reset search",
    "Search contacts …" : "Search contacts …",
    "Could not load your contacts" : "Could not load your contacts",
    "No contacts found" : "No contacts found",
    "Show all contacts" : "Show all contacts",
    "Install the Contacts app" : "Install the Contacts app",
    "Loading your contacts …" : "Loading your contacts …",
    "Looking for {term} …" : "Looking for {term} …",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Search starts once you start typing and results may be reached with the arrow keys",
    "Search for {name} only" : "Search for {name} only",
    "Loading more results …" : "Loading more results …",
    "Search" : "Search",
    "No results for {query}" : "No results for {query}",
    "Press Enter to start searching" : "Press Enter to start searching",
    "An error occurred while searching for {type}" : "An error occurred while searching for {type}",
    "Forgot password?" : "Forgot password?",
    "Back to login form" : "Back to login form",
    "Back" : "Back",
    "Login form is disabled." : "Login form is disabled.",
    "Edit Profile" : "Edit Profile",
    "The headline and about sections will show up here" : "The headline and about sections will show up here",
    "You have not added any info yet" : "You have not added any info yet",
    "{user} has not added any info yet" : "{user} has not added any info yet",
    "Error opening the user status modal, try hard refreshing the page" : "Error opening the user status modal, try hard refreshing the page",
    "More actions" : "More actions",
    "This browser is not supported" : "This browser is not supported",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Your browser is not supported. Please upgrade to a newer version or a supported one.",
    "Continue with this unsupported browser" : "Continue with this unsupported browser",
    "Supported versions" : "Supported versions",
    "{name} version {version} and above" : "{name} version {version} and above",
    "Search {types} …" : "Search {types} …",
    "Choose {file}" : "Choose {file}",
    "Choose" : "Choose",
    "Copy to {target}" : "Copy to {target}",
    "Copy" : "Copy",
    "Move to {target}" : "Move to {target}",
    "Move" : "Move",
    "OK" : "OK",
    "read-only" : "read-only",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} file conflict","{count} file conflicts"],
    "One file conflict" : "One file conflict",
    "New Files" : "New Files",
    "Already existing files" : "Already existing files",
    "Which files do you want to keep?" : "Which files do you want to keep?",
    "If you select both versions, the copied file will have a number added to its name." : "If you select both versions, the copied file will have a number added to its name.",
    "Cancel" : "Cancel",
    "Continue" : "Continue",
    "(all selected)" : "(all selected)",
    "({count} selected)" : "({count} selected)",
    "Error loading file exists template" : "Error loading file exists template",
    "Saving …" : "Saving …",
    "seconds ago" : "seconds ago",
    "Connection to server lost" : "Connection to server lost",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem loading page, reloading in %n second","Problem loading page, reloading in %n seconds"],
    "Add to a project" : "Add to a project",
    "Show details" : "Show details",
    "Hide details" : "Hide details",
    "Rename project" : "Rename project",
    "Failed to rename the project" : "Failed to rename the project",
    "Failed to create a project" : "Failed to create a project",
    "Failed to add the item to the project" : "Failed to add the item to the project",
    "Connect items to a project to make them easier to find" : "Connect items to a project to make them easier to find",
    "Type to search for existing projects" : "Type to search for existing projects",
    "New in" : "New in",
    "View changelog" : "View changelog",
    "Very weak password" : "Very weak password",
    "Weak password" : "Weak password",
    "So-so password" : "So-so password",
    "Good password" : "Good password",
    "Strong password" : "Strong password",
    "No action available" : "No action available",
    "Error fetching contact actions" : "Error fetching contact actions",
    "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialog",
    "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
    "Restricted" : "Restricted",
    "Invisible" : "Invisible",
    "Delete" : "Delete",
    "Rename" : "Rename",
    "Collaborative tags" : "Collaborative tags",
    "No tags found" : "No tags found",
    "Personal" : "Personal",
    "Accounts" : "Accounts",
    "Admin" : "Admin",
    "Help" : "Help",
    "Access forbidden" : "Access forbidden",
    "Profile not found" : "Profile not found",
    "The profile does not exist." : "The profile does not exist.",
    "Back to %s" : "Back to %s",
    "Page not found" : "Page not found",
    "The page could not be found on the server or you may not be allowed to view it." : "The page could not be found on the server or you may not be allowed to view it.",
    "Too many requests" : "Too many requests",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
    "Error" : "Error",
    "Internal Server Error" : "Internal Server Error",
    "The server was unable to complete your request." : "The server was unable to complete your request.",
    "If this happens again, please send the technical details below to the server administrator." : "If this happens again, please send the technical details below to the server administrator.",
    "More details can be found in the server log." : "More details can be found in the server log.",
    "Technical details" : "Technical details",
    "Remote Address: %s" : "Remote Address: %s",
    "Request ID: %s" : "Request ID: %s",
    "Type: %s" : "Type: %s",
    "Code: %s" : "Code: %s",
    "Message: %s" : "Message: %s",
    "File: %s" : "File: %s",
    "Line: %s" : "Line: %s",
    "Trace" : "Trace",
    "Security warning" : "Security warning",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
    "Create an <strong>admin account</strong>" : "Create an <strong>admin account</strong>",
    "Show password" : "Show password",
    "Toggle password visibility" : "Toggle password visibility",
    "Storage & database" : "Storage & database",
    "Data folder" : "Data folder",
    "Configure the database" : "Configure the database",
    "Only %s is available." : "Only %s is available.",
    "Install and activate additional PHP modules to choose other database types." : "Install and activate additional PHP modules to choose other database types.",
    "For more details check out the documentation." : "For more details check out the documentation.",
    "Database password" : "Database password",
    "Database name" : "Database name",
    "Database tablespace" : "Database tablespace",
    "Database host" : "Database host",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
    "Performance warning" : "Performance warning",
    "You chose SQLite as database." : "You chose SQLite as database.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
    "Install" : "Install",
    "Installing …" : "Installing …",
    "Need help?" : "Need help?",
    "See the documentation" : "See the documentation",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Could not remove CAN_INSTALL from the config folder. Please remove this file manually.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page.",
    "Skip to main content" : "Skip to main content",
    "Skip to navigation of app" : "Skip to navigation of app",
    "Go to %s" : "Go to %s",
    "Get your own free account" : "Get your own free account",
    "Connect to your account" : "Connect to your account",
    "Please log in before granting %1$s access to your %2$s account." : "Please log in before granting %1$s access to your %2$s account.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator.",
    "App password" : "App password",
    "Grant access" : "Grant access",
    "Alternative log in using app password" : "Alternative log in using app password",
    "Account access" : "Account access",
    "Currently logged in as %1$s (%2$s)." : "Currently logged in as %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "You are about to grant %1$s access to your %2$s account.",
    "Account connected" : "Account connected",
    "Your client should now be connected!" : "Your client should now be connected!",
    "You can close this window." : "You can close this window.",
    "Previous" : "Previous",
    "This share is password-protected" : "This share is password-protected",
    "The password is wrong or expired. Please try again or request a new one." : "The password is wrong or expired. Please try again or request a new one.",
    "Please type in your email address to request a temporary password" : "Please type in your email address to request a temporary password",
    "Email address" : "Email address",
    "Password sent!" : "Password sent!",
    "You are not authorized to request a password for this share" : "You are not authorized to request a password for this share",
    "Two-factor authentication" : "Two-factor authentication",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Enhanced security is enabled for your account. Choose a second factor for authentication:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Could not load at least one of your enabled two-factor auth methods. Please contact your admin.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication.",
    "Set up two-factor authentication" : "Set up two-factor authentication",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance.",
    "Use backup code" : "Use backup code",
    "Cancel login" : "Cancel login",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Enhanced security is enforced for your account. Choose which provider to set up:",
    "Error while validating your second factor" : "Error while validating your second factor",
    "Access through untrusted domain" : "Access through untrusted domain",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Further information how to configure this can be found in the %1$sdocumentation%2$s.",
    "App update required" : "App update required",
    "%1$s will be updated to version %2$s" : "%1$s will be updated to version %2$s",
    "The following apps will be updated:" : "The following apps will be updated:",
    "These incompatible apps will be disabled:" : "These incompatible apps will be disabled:",
    "The theme %s has been disabled." : "The theme %s has been disabled.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
    "Start update" : "Start update",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:",
    "Detailed logs" : "Detailed logs",
    "Update needed" : "Update needed",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure.",
    "Upgrade via web on my own risk" : "Upgrade via web on my own risk",
    "Maintenance mode" : "Maintenance mode",
    "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
    "This page will refresh itself when the instance is available again." : "This page will refresh itself when the instance is available again.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contact your system administrator if this message persists or appeared unexpectedly.",
    "The user limit of this instance is reached." : "The user limit of this instance is reached.",
    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly.",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!",
    "Currently open" : "Currently open",
    "Wrong username or password." : "Wrong username or password.",
    "User disabled" : "User disabled",
    "Username or email" : "Username or email",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help.",
    "Apps and Settings" : "Apps and Settings",
    "Error loading message template: {error}" : "Error loading message template: {error}",
    "Users" : "Users",
    "Username" : "Username",
    "Database user" : "Database user",
    "This action requires you to confirm your password" : "This action requires you to confirm your password",
    "Confirm your password" : "Confirm your password",
    "Confirm" : "Confirm",
    "App token" : "App token",
    "Alternative log in using app token" : "Alternative log in using app token",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Please use the command line updater because you have a big instance with more than 50 users."
},
"nplurals=2; plural=(n!=1);");
